@@ -16,6 +16,7 @@ __all__ = [
     "Section",
     "Serialization",
     "Symbol",
+    "SymbolicExpression",
     "SymAddrAddr",
     "SymAddrConst",
     "SymStackConst",
@@ -32,7 +33,12 @@ from .offset import Offset
 from .section import Section
 from .serialization import Serialization
 from .symbol import Symbol
-from .symbolicexpression import SymAddrAddr, SymAddrConst, SymStackConst
+from .symbolicexpression import (
+    SymAddrAddr,
+    SymAddrConst,
+    SymbolicExpression,
+    SymStackConst,
+)
 from .version import API_VERSION
 
 __version__ = API_VERSION
